@@ -1,149 +1,140 @@
 package OpenAPI::Linter::Location;
 
-$OpenAPI::Linter::VERSION   = '0.16';
-$OpenAPI::Linter::AUTHORITY = 'cpan:MANWAR';
+$OpenAPI::Linter::Location::VERSION   = '0.17';
+$OpenAPI::Linter::Location::AUTHORITY = 'cpan:MANWAR';
+
+use strict;
+use warnings;
+use overload
+    '""'     => \&to_string,
+    fallback => 1;
 
 =head1 NAME
 
-OpenAPI::Linter::Location - Represents file location information for OpenAPI specification issues
+OpenAPI::Linter::Location - File location information for OpenAPI spec issues
 
 =head1 VERSION
 
-Version 0.16
-
-=cut
-
-our $VERSION = '0.16';
+Version 0.17
 
 =head1 SYNOPSIS
 
     use OpenAPI::Linter::Location;
 
-    # Create a location object
-    my $location = OpenAPI::Linter::Location->new('openapi.yaml', 10, 5);
+    my $loc = OpenAPI::Linter::Location->new(
+        file   => 'openapi.yaml',
+        path   => 'paths./users.get.responses',
+        line   => 42,
+        column => 5,
+    );
 
-    # Convert to string representation
-    print $location->to_string;  # "openapi.yaml:10:5"
-
-    # Access location components directly
-    print $location->{file};    # "openapi.yaml"
-    print $location->{line};    # 10
-    print $location->{column};  # 5
+    print $loc;             # "paths./users.get.responses"  (stringifies to path)
+    print $loc->to_string;  # "paths./users.get.responses"
+    print $loc->file;       # "openapi.yaml"
+    print $loc->line;       # 42
+    print $loc->column;     # 5
+    print $loc->position;   # "openapi.yaml:42:5"
 
 =head1 DESCRIPTION
 
-C<OpenAPI::Linter::Location> represents a specific location within an OpenAPI specification
-file. It tracks the file name, line number, and column number where an issue or element
-is located.
+Represents a specific location within an OpenAPI specification file, combining
+a dot-separated schema path (e.g. C<paths./users.get>) with an optional file
+name, line number, and column number.
 
-This class is used internally by L<OpenAPI::Linter> to provide precise location
-information for validation errors and linting issues, making it easier for developers
-to locate and fix problems in their OpenAPI specifications.
+The object stringifies to its C<path> value, so existing code that treats
+issue locations as plain strings continues to work without modification.
 
 =head1 METHODS
 
 =head2 new
 
-Creates a new C<OpenAPI::Linter::Location> instance.
+    my $loc = OpenAPI::Linter::Location->new(%args);
 
-It returns a blessed hash reference containing the location information.
-
-Parameters:
+Named arguments:
 
 =over 4
 
-=item * file
+=item C<path> (required)
 
-The file path where the issue occurred. This can be a relative or absolute path.
+Dot-separated path within the spec, e.g. C<paths./users.get.responses.200>.
 
-=item * line
+=item C<file> (optional)
 
-The line number within the file (1-based).
+The spec file name or C<internal_data> for in-memory specs.
 
-=item * column
+=item C<line> (optional)
 
-The column number within the line (1-based).
+1-based line number within the file. C<0> means unknown.
+
+=item C<column> (optional)
+
+1-based column number within the file. C<0> means unknown.
 
 =back
 
-    my $location = OpenAPI::Linter::Location->new($file, $line, $column);
-
 =cut
 
-use strict;
-use warnings;
-
 sub new {
-    my ($class, $file, $line, $column) = @_;
+    my ($class, %args) = @_;
     return bless {
-        file   => $file,
-        line   => $line,
-        column => $column
+        path   => $args{path}   // '',
+        file   => $args{file}   // 'unknown',
+        line   => $args{line}   // 0,
+        column => $args{column} // 0,
     }, $class;
 }
 
 =head2 to_string
 
-Returns a string representation of the location in the format C<file:line:column>.
-
-This format is commonly used by development tools, IDEs, and command-line utilities
-to quickly navigate to specific locations in source files.
-
-Example:
-
-    my $location_str = $location->to_string;
-
-    openapi.yaml:15:8
-    spec.json:42:3
-    input:1:1
+Returns the dot-separated path string. This is also what the object produces
+when used in string context.
 
 =cut
 
-sub to_string {
+sub to_string { $_[0]->{path} }
+
+=head2 file
+
+Returns the file name associated with this location.
+
+=cut
+
+sub file   { $_[0]->{file}   }
+
+=head2 line
+
+Returns the line number (1-based). Returns C<0> if unknown.
+
+=cut
+
+sub line   { $_[0]->{line}   }
+
+=head2 column
+
+Returns the column number (1-based). Returns C<0> if unknown.
+
+=cut
+
+sub column { $_[0]->{column} }
+
+=head2 position
+
+Returns the full C<file:line:column> position string, e.g.
+C<openapi.yaml:42:5>. Returns C<unknown> if line information is unavailable.
+
+=cut
+
+sub position {
     my ($self) = @_;
-    return $self->{file} . ":" . $self->{line} . ":" . $self->{column};
+    return 'unknown' unless $self->{line};
+    return sprintf '%s:%d:%d', $self->{file}, $self->{line}, $self->{column};
 }
 
-=head1 ACCESSORS
+=head1 OVERLOADING
 
-While C<OpenAPI::Linter::Location> uses a simple blessed hash structure rather
-than formal accessors, the following hash keys are available:
-
-=over 4
-
-=item * file
-
-The file path associated with this location.
-
-=item * line
-
-The line number (1-based).
-
-=item * column
-
-The column number (1-based).
-
-=back
-
-Example:
-
-    print "File: $location->{file}\n";
-    print "Line: $location->{line}\n";
-    print "Column: $location->{column}\n";
-
-=head1 Usage with OpenAPI::Linter
-
-Location objects are automatically created and used by L<OpenAPI::Linter>
-when processing OpenAPI specifications. Each issue returned by C<find_issues>
-or C<validate_schema> includes a location field:
-
-    my $linter = OpenAPI::Linter->new(spec => 'openapi.yaml');
-    my @issues = $linter->find_issues;
-
-    foreach my $issue (@issues) {
-        print "Issue at $issue->{location}: $issue->{message}\n";
-        # Example: "Issue at openapi.yaml:10:5: Missing info.title"
-    }
+The object stringifies to its C<path> value via C<"">. This preserves
+backwards compatibility with code that compares or prints C<$issue->{location}>
+as a plain string.
 
 =head1 AUTHOR
 
@@ -185,26 +176,21 @@ L<https://metacpan.org/dist/OpenAPI-Linter/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2025 Mohammad Sajid Anwar.
+Copyright (C) 2026 Mohammad Sajid Anwar.
 
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic License (2.0). You may obtain a  copy of the full
 license at:
-
 L<http://www.perlfoundation.org/artistic_license_2_0>
-
 Any  use,  modification, and distribution of the Standard or Modified Versions is
 governed by this Artistic License.By using, modifying or distributing the Package,
 you accept this license. Do not use, modify, or distribute the Package, if you do
 not accept this license.
-
 If your Modified Version has been derived from a Modified Version made by someone
 other than you,you are nevertheless required to ensure that your Modified Version
  complies with the requirements of this license.
-
 This  license  does  not grant you the right to use any trademark,  service mark,
 tradename, or logo of the Copyright Holder.
-
 This license includes the non-exclusive, worldwide, free-of-charge patent license
 to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
 Package with respect to any patent claims licensable by the Copyright Holder that
@@ -212,7 +198,6 @@ are  necessarily  infringed  by  the  Package. If you institute patent litigatio
 (including  a  cross-claim  or  counterclaim) against any party alleging that the
 Package constitutes direct or contributory patent infringement,then this Artistic
 License to you shall terminate on the date that such litigation is filed.
-
 Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
 CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
 WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
